@@ -686,13 +686,19 @@ void cid_calls_merge(session_t *session) {
     if (debug) {
       fprintf(stderr, "Using %s as source for isdnlog data.\n", calls_filename);
     }
-    /* do a binary search on the file for the desired starting time if needed */
     if (session->option_calls_merge_max_days) {
+      /* binary search on the file for the desired starting time if needed */
+      if (debug >= 3) {
+	fprintf(stderr, "Binary search in calls file...\n");
+      }
       low = 0;
       fseek(f, 0, SEEK_END);
       high = ftell(f);
       
       while (high - low > 200) {
+	if (debug >= 3) {
+	  fprintf(stderr, "low = %d, high = %d\n", low, high);
+	}
         mid = (low + high) / 2;
         fseek(f, mid, SEEK_SET);
 	getline(&line, &linelength, f); /* discard potentially partial line */
@@ -780,9 +786,8 @@ void cid_calls_merge(session_t *session) {
       cache = linearr[CID_COL_TIME];
       free(linearr[CID_COL_DURATION]);
     }
+    free(cache);
 
-    free(linearr[CID_COL_TIME]);
-    
     cid_normalize(session);
   
     if (fclose(f))
