@@ -43,14 +43,14 @@ char *un_vanity(char *s);
 char *timediff_str(time_t time1, time_t time0);
 char *ltostr(long int i);
 void execute(char *command);
-char *get_homedir();
+char *get_homedir(void);
 int touch_dir(char *dirname);
-int touch_dotdir();
+int touch_dotdir(void);
 int substitute(char **s, char *x, char *y);
 char *util_digitstime(time_t *time);
 char* stripchr(char* s, char c);
 char* filename_extension(char* fn);
-int output_codeset_save();
+int output_codeset_save(void);
 int output_codeset_set(char* codeset);
 
 #endif /* util.h */
